summaryrefslogtreecommitdiff
path: root/content/handlers/html/table.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/handlers/html/table.h')
-rw-r--r--content/handlers/html/table.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/content/handlers/html/table.h b/content/handlers/html/table.h
index ac4af25ad..557032b06 100644
--- a/content/handlers/html/table.h
+++ b/content/handlers/html/table.h
@@ -33,24 +33,24 @@ struct box;
/**
* Determine the column width types for a table.
*
* \param len_ctx Length conversion context
* \param table box of type BOX_TABLE
* \return true on success, false on memory exhaustion
*
* The table->col array is allocated and type and width are filled in for each
* column.
*/
-bool table_calculate_column_types(const nscss_len_ctx *len_ctx, struct box *table);
+bool table_calculate_column_types(const css_unit_ctx *unit_len_ctx, struct box *table);
/**
* Calculate used values of border-{trbl}-{style,color,width} for table cells.
*
* \param len_ctx Length conversion context
* \param cell Table cell to consider
*
* \post \a cell's border array is populated
*/
-void table_used_border_for_cell(const nscss_len_ctx *len_ctx, struct box *cell);
+void table_used_border_for_cell(const css_unit_ctx *unit_len_ctx, struct box *cell);
#endif
@@ -33,24 +33,24 @@ struct box;
* Determine the column width types for a table.
*
- * \param len_ctx Length conversion context
+ * \param unit_len_ctx Length conversion context
* \param table box of type BOX_TABLE
* \return true on success, false on memory exhaustion
@@ -33,24 +33,24 @@ struct box;
* Calculate used values of border-{trbl}-{style,color,width} for table cells.
*
- * \param len_ctx Length conversion context
+ * \param unit_len_ctx Length conversion context
* \param cell Table cell to consider
*